API docs for “spamfighter.utils.time”

# Module s.u.time

Part of spamfighter.utils View Source

Модуль подсчета "неточного" времени (разрешение одна секунда). Доступен вариант для использования в unit-тестах.

Модуль экспортирует функцию `time()`, которая возвращает целое число секунд, начиная с некоторой даты. В production - это переменная, которая обновляется (осуществляется системный вызов) не чаще, чем раз в секунду.

При использовании в тестах можно подменить реальное время модельным. После вызова функции startUpTestTimer функция time() буде возвращать таймер, значение которого можно корректировать

Function | time | Undocumented
Function | startUpTestTimer | Undocumented
Function | advanceTestTimer | Undocumented
Function | setTestTimer | Undocumented
Function | tearDownTestTimer | Undocumented
Function | _inaccurate_time | Undocumented
Function | _inaccurate_timer_tick | Undocumented
Function | _start_inaccurate_timer | Undocumented
Function | _test_time | Undocumented

def _inaccurate_time(): (source)
Undocumented
def time(): (source)
Undocumented
def _inaccurate_timer_tick(): (source)
Undocumented
def _start_inaccurate_timer(): (source)
Undocumented
def _test_time(): (source)
Undocumented
def startUpTestTimer(initial=0): (source)
Undocumented
def advanceTestTimer(step): (source)
Undocumented
def setTestTimer(value): (source)
Undocumented
def tearDownTestTimer(): (source)
Undocumented